#clear workspace
rm(list = ls())
#set true to export png
DoPNG <- TRUE 
#DoPNG <- FALSE

#scrub, describe
if (!require("psych")) {
   install.packages("psych", dependencies = TRUE)
   library(psych)
   }
#recode   
if (!require("car")) {
   install.packages("car", dependencies = TRUE)
   library(car)
   }
#heatmap
if (!require("lattice")) {
   install.packages("lattice", dependencies = TRUE)
   library(lattice)
   }

#load data
print("Reading data")
tmpdata <- read.table("20160219_DrawSurvey.csv",header=TRUE,sep=";")

print("Cleaning up")
draw<-subset(tmpdata,select=c(1,3,4,6:16)) 
draw<-scrub(draw,1:14,min=1)
#shorten colnames
colnames(draw) = c("participant","Usage","Expertise","Simple Shapes","Lines","Connectors","Freeform Curves","Symbols","3D Objects","Artwork from Gallery","Layers","Multiple Pages","Import/Export of\nVector Graphics","Import/Export of\nRaster Graphics") 
rm(tmpdata)

#define labels
lUsage <- c("never","rarely","regularly","frequently")
lExpertise <- c("basic","intermediate","advanced","expert")

#summary
print("Summarizing data")
print(describe(draw))

#heatmap
cScale <- 1.2
ShowValues <- function(x, y, z, ...) {
                panel.levelplot(x,y,z, ...)
                panel.text(x, y, round(z,1), cex=cScale)
               }
  
if (DoPNG) png("DrawUsage-Heatmap.png",width=600,height=600)
print(levelplot(table(draw$Usage,draw$Expertise),
		  xlab=list(cex=cScale+0.1,label="Usage"),
		  ylab=list(cex=cScale+0.1,label="Expertise"),
		  main=list(cex=cScale+0.1,label="Number of Users"),
		  xlim=lUsage,
		  ylim=lExpertise,
		  cuts=3,
		  col.regions= cm.colors(4),
		  scales=list(cex=cScale),
		  panel=ShowValues,
		  )
	)	  
if (DoPNG) dev.off() else dev.new()

#special boxplot	
if (DoPNG) png("DrawUsage-BoxPlot.png",width=600,height=600,pointsize=14)
bpfunc<-function(x){
		  m<-mean(x,na.rm=TRUE)
		  z1<-mean(x[draw$Usage<=2 & draw$Expertise<=2],na.rm=TRUE)
		  z2<-mean(x[draw$Usage<=2 & draw$Expertise>2],na.rm=TRUE)
		  z3<-mean(x[draw$Usage>2 & draw$Expertise<=2],na.rm=TRUE)
		  z4<-mean(x[draw$Usage>2 & draw$Expertise>2],na.rm=TRUE)
		  c(z1,z2,m,z3,z4)}
		  
bp<-boxplot(draw[4:14],plot=FALSE)
bp$stats <- sapply(draw[4:14], bpfunc)
bp$group <- bp$out <- numeric(0) # no outliers when whiskers go to min and max
par(mar=c(3,10,2,2))
par(las=1)
bxp(bp, horizontal=TRUE, main="Relevance of Features",ylim=c(1,6),axes=FALSE)
box()
grid(2,NA)#NA,length(bp$names)+1)
axis(side=2,labels=colnames(draw[4:14]),at=c(1:11))
axis(side=1,labels=c("never","","","","","frequently"),at=c(1:6))
if (DoPNG) dev.off() else dev.new()

#same data as profile plot
if (DoPNG) png("DrawUsage-ProfilePlot.png",width=600,height=600,pointsize=14)
par(mar=c(3,10,2,2))
par(las=1)
plot(NULL,xlim=c(1,6),ylim=c(1,11),type="n",axes=FALSE,main="Relevance of Features",xlab="",ylab="")
box()
grid(2,NA)#NA,length(bp$names)+1)
axis(side=2,labels=colnames(draw[4:14]),at=c(1:11))
axis(side=1,labels=c("never","","","","","frequently"),at=c(1:6))

lines(bp$stats[1,],c(1:11),lty=3,lwd=1,col="red")
lines(bp$stats[2,],c(1:11),lty=2,lwd=1,col="red")
lines(bp$stats[3,],c(1:11),lty=1,lwd=2)
lines(bp$stats[4,],c(1:11),lty=2,lwd=1,col="blue")
lines(bp$stats[5,],c(1:11),lty=3,lwd=1,col="blue")

legend("bottomleft", c("U<=2,E<=2", "U<=2,E>2", "Average","U>2,E<=2", "U>2,E>2"),lty=c(3,2,1,2,3),col=c("red","red","black","blue","blue"))
if (DoPNG) dev.off()
